# Extensions

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**topic_type** | **list[str]** |  | 
**topic_status** | **list[str]** |  | 
**topic_label** | **list[str]** |  | 
**priority** | **list[str]** |  | 
**user_id_type** | **list[str]** |  | [optional] [readonly] 
**stage** | **list[str]** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


